@@ -29,10 +29,15 @@ Implementation Notes
 """
 
 # imports
+# Support both 8.x.x and 9.x.x. Remove 8.x method when discontinued.
+try:
+    from fourwire import FourWire  # 9.x method
+    from busdisplay import BusDisplay
+except ImportError:
+    from displayio import FourWire  # 8.x method
+    from displayio import Display as BusDisplay
 
-import displayio
-
-__version__ = "1.3.8"
+__version__ = "1.4.2"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_HX8357.git"
 
 _INIT_SEQUENCE = (
@@ -56,9 +61,10 @@ _INIT_SEQUENCE = (
     b"\x29\x80\x32"  # _DISPON and delay 50 ms
 )
 
+
 # pylint: disable=too-few-public-methods
-class HX8357(displayio.Display):
+class HX8357(BusDisplay):
     """HX8357D driver"""
 
-    def __init__(self, bus: displayio.FourWire, **kwargs) -> None:
+    def __init__(self, bus: FourWire, **kwargs) -> None:
         super().__init__(bus, _INIT_SEQUENCE, **kwargs)
